============
Installation
============

At the command line:

.. code-block:: shell

   $ pip install os-brick

Or, if you have virtualenvwrapper installed:

.. code-block:: shell

   $ mkvirtualenv os-brick
   $ pip install os-brick

Or, from source:

.. code-block:: shell

   $ git clone https://github.com/openstack/os-brick
   $ cd os-brick
   $ python setup.py install
